import * as cdk from '@aws-cdk/core';
import * as iam from '@aws-cdk/aws-iam';
import * as apigateway from '@aws-cdk/aws-apigateway';
export interface GenericRestApiAwsIntegrationProps {
    /**
     * The RestApi resource to which a method will be added and integrated with the AWS service
     */
    restApiResource: apigateway.Resource;
    /**
     * The status code returned by RestApi on a successful request
     *
     * @default "200"
     */
    successResponseStatusCode?: string;
    /**
     * The status code returned by RestApi on a failing request
     *
     * @default "503"
     */
    failureResponseStatusCode?: string;
}
export declare abstract class GenericRestApiAwsIntegration extends cdk.Construct {
    /** @returns RestApi::Method to which the AwsIntegration was integrated to */
    protected readonly restApiMethod: apigateway.Method;
    protected abstract configureAwsService(id: string, props: GenericRestApiAwsIntegrationProps): void;
    protected abstract init(id: string, props: GenericRestApiAwsIntegrationProps): void;
    protected awsService: string;
    protected integrationHttpVerb: string;
    protected integrationPath?: string;
    protected integrationAction?: string;
    protected requestTemplates: {
        [contentType: string]: string;
    };
    protected successResponseTemplates: {
        [contentType: string]: string;
    };
    protected failureResponseTemplates: {
        [contentType: string]: string;
    };
    readonly integrationRole: iam.IRole;
    protected constructor(scope: cdk.Construct, id: string, props: GenericRestApiAwsIntegrationProps);
    private addIntegration;
    private addIntegrationRole;
}
