import * as sfn from '@aws-cdk/aws-stepfunctions';
import * as cdk from '@aws-cdk/core';
import { GenericRestApiAwsIntegration, GenericRestApiAwsIntegrationProps } from "./generic-rest-api-aws-integration";
/**
 * Integrates a Step Function with ApiGateway(RestApi) by starting an Execution on http request
 */
export interface StepFunctionsRestApiIntegrationProps extends GenericRestApiAwsIntegrationProps {
    /**
     * The target Step Functions StateMachine which will be executed by the RestApi Integration
     */
    stateMachine: sfn.StateMachine;
    /**
     *  Integration request mapping templates
     *
     *  reference: https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-mapping-template-reference.html
     *
     *  @default {"application/json": "Action=Publish&TopicArn=$util.urlEncode('" + props.stateMachine.topicArn + "')&Message=$util.urlEncode($input.body)"}
     */
    requestTemplates?: {
        [contentType: string]: string;
    };
}
export declare class StepFunctionsRestApiIntegration extends GenericRestApiAwsIntegration {
    constructor(scope: cdk.Construct, id: string, props: StepFunctionsRestApiIntegrationProps);
    init(id: string, props: StepFunctionsRestApiIntegrationProps): void;
    configureAwsService(id: string, props: StepFunctionsRestApiIntegrationProps): void;
}
